/**
 * Copyright 2023 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {logger} from "firebase-functions/v1";

/**
 * A function to determine whether field values exist on the object
 * @param {FirebaseFirestore.DocumentData} afterObject
 * @param {string} field
 * @return {boolean}
 */
export function fieldValueExists(
  afterObject: FirebaseFirestore.DocumentData | undefined,
  field: string): boolean {
  if (afterObject == undefined) {
    return false;
  }
  const aValue = afterObject[field];
  if (aValue == undefined) {
    logger.log(`missing value ${aValue} for field ${field}, cannot compute`);
    return false;
  }
  return true;
}